@@ -14,3 +14,6 @@ SfCrawler = sf_crawler.SfCrawler
 
 from hawkdata.utils.crawlers import cb_crawler
 CbCrawler = cb_crawler.CbCrawler
+
+from hawkdata.utils.crawlers import cstats_crawler
+CStatsCrawler = cstats_crawler.CStatsCrawler
